@@ -6,12 +6,13 @@
  *
  * Copyright 2000, 2001 Ximian, Inc.
  */
+
+#undef GTK_DISABLE_DEPRECATED
+
 #include <config.h>
 #include <string.h>
 
-#include <gtk/gtkstock.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtkiconfactory.h>
+#include <gtk/gtk.h>
 
 #include <libgnome/gnome-help.h>
 #include <libgnome/gnome-init.h>
